import React, { useState } from 'react';

function BookmarksSection({ bookmarks, onLoadBookmark, onRemoveBookmark }) {
  const [expanded, setExpanded] = useState(true);

  const formatUrl = (url) => {
    if (url.length > 40) {
      return url.substring(0, 37) + '...';
    }
    return url;
  };

  return (
    <div className="bookmarks-section form-item" style={{ marginTop: '24px' }}>
      <details className={`claro-details${expanded ? ' is-open' : ''}`}>
        <summary className="claro-details__summary" onClick={(e) => {
          e.preventDefault();
          setExpanded(!expanded);
        }}>
          <span className="claro-details__summary-content">Bookmarks</span>
        </summary>
        
        <div className="claro-details__wrapper">
          {bookmarks.length === 0 ? (
            <div className="form-item__description">
              No bookmarks saved yet
            </div>
          ) : (
            <div className="card" style={{ maxHeight: 300, overflow: 'auto' }}>
              <ul className="item-list">
                {bookmarks.map((bookmark) => (
                  <li key={bookmark.id} className="item-list__item" style={{ display: 'flex', justifyContent: 'space-between', alignItems: 'center', borderBottom: '1px solid #ddd', padding: '8px 0' }}>
                    <div style={{ overflow: 'hidden', flex: 1 }}>
                      <div style={{ fontWeight: 500, overflow: 'hidden', textOverflow: 'ellipsis', whiteSpace: 'nowrap' }}>
                        {bookmark.name}
                      </div>
                      <div style={{ fontSize: '0.85em', color: '#666', overflow: 'hidden', textOverflow: 'ellipsis', whiteSpace: 'nowrap' }}>
                        {formatUrl(bookmark.url)}
                      </div>
                    </div>
                    <div>
                      <button 
                        className="button button--small"
                        onClick={() => onLoadBookmark(bookmark)}
                        title="Load this bookmark"
                        style={{ marginRight: '8px' }}
                      >
                        ▶
                      </button>
                      
                      <button 
                        className="button button--small button--danger"
                        onClick={() => onRemoveBookmark(bookmark.id)}
                        title="Remove bookmark"
                      >
                        ✕
                      </button>
                    </div>
                  </li>
                ))}
              </ul>
            </div>
          )}
        </div>
      </details>
    </div>
  );
}

export default BookmarksSection;